//
// nono
// Copyright (C) 2021 nono project
// Licensed under nono-license.txt
//

//
// シリアルポートの None ドライバ
//

#include "comdriver_none.h"

// コンストラクタ
COMDriverNone::COMDriverNone(HostDevice *hostdev_)
	: inherited(hostdev_, "none")
{
}

// デストラクタ
COMDriverNone::~COMDriverNone()
{
}

// 1バイト書き出し
void
COMDriverNone::Write(uint32 data)
{
}

// 1バイト読み込み
int
COMDriverNone::Read()
{
	return NODATA;
}
